pub enum CohereInputType {
SearchDocument,
SearchQuery,
Classification,
Clustering,
}Expand description
Input type for Cohere embeddings.
Using the correct input type is important for retrieval quality.
Variants
SearchDocument
For embedding documents to be stored in a vector database.
SearchQuery
For embedding queries used to search the vector database.
Classification
For classification tasks.
Clustering
For clustering tasks.
Implementations